[![Red cogs](https://img.shields.io/badge/Red--DiscordBot-cogs-red.svg)](https://github.com/Cog-Creators/Red-DiscordBot/tree/V3/develop)
[![discord.py](https://img.shields.io/badge/discord-py-blue.svg)](https://github.com/Rapptz/discord.py)
[![ReadTheDocs](https://img.shields.io/readthedocs/dronefly/latest?label=documentation)](https://dronefly.readthedocs.io)

# Dronefly core

This branch contains an incomplete rewrite of Dronefly bot's core components,
and as such is not yet suitable for production use. Please use dronefly's main
branch instead, which includes the stable version of Dronefly core.

# Dronefly bot

Dronefly is a bot for naturalists that gives users access to
[iNaturalist](https://www.inaturalist.org) on [Discord](https://discord.com)
chat.

